import { ChangeDetectorRef, OnChanges, OnInit } from '@angular/core';
import { DrawerService } from './service/drawer.service';
import { StateListener } from './state-listener.component';
import { Subscription } from 'rxjs';
/**
 * [Drawer Component](https://brightlayer-ui-components.github.io/angular/?path=/info/components-drawer--readme)
 *
 * The `<blui-drawer>` is used to organize content (typically navigation links) within a `<blui-drawer-layout>`.
 * The `<blui-drawer>` includes helper components for `<blui-drawer-header>`, `<blui-drawer-subheader>`, `<blui-drawer-body>`, `<blui-drawer-nav-group>`, `<blui-drawer-footer>`, and `<blui-drawer-layout>` to help organize the content.
 */
export declare class DrawerComponent extends StateListener implements OnInit, OnChanges {
    /** Enables a condensed view for the `rail` variant which removes NavItem labels and shows tooltips instead
     *
     * @default false
     * */
    condensed: boolean;
    /** Hides tooltips on hover for the `rail` variant
     *
     * @default false
     * */
    disableRailTooltip: boolean;
    /** If true, NavItems will not have a bold title when a child NavItem is selected
     *
     * @default false
     * */
    disableActiveItemParentStyles: boolean;
    /** State for the drawer */
    open: boolean;
    /** Automatically open the drawer on hover when closed (persistent variant only) */
    openOnHover: boolean;
    /** Delay in milliseconds before a hover event opens the drawer (persistent variant only)
     *
     * @default 500
     * */
    openOnHoverDelay: number;
    /** Toggle a side border instead of shadow
     *
     * @default false
     * */
    sideBorder: boolean;
    hoverDelayTimeout: any;
    drawerSelectionListener: Subscription;
    constructor(drawerService: DrawerService, changeDetectorRef: ChangeDetectorRef);
    ngOnInit(): void;
    ngOnChanges(): void;
    hoverDrawer(): void;
    unhoverDrawer(): void;
    listenForDrawerSelection(): void;
    isTemporaryVariant(): boolean;
}
